#!/bin/sh

echo "The install.sh is installing the SeizeDesktop's files."
echo ""
echo "Installing files..."
echo `ln -sf /usr/local/JDE/SeizeDesktop/bin/SeizeDesktop.app /usr/local/bin`
echo `ln -sf /usr/local/JDE/SeizeDesktop/bin/PrefDesktop.app /usr/local/bin`

echo "Done."
